summaryrefslogtreecommitdiff
path: root/compiler/typecheck/TcPatSyn.hs
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2020-03-18 10:44:56 +0100
committerMarge Bot <ben+marge-bot@smart-cactus.org>2020-03-29 17:28:51 -0400
commit1941ef4f050c0dfcb68229641fcbbde3a10f1072 (patch)
tree8e25a61af77696d3022d35cc277b5db5af540f03 /compiler/typecheck/TcPatSyn.hs
parent1c446220250dcada51d4bb33a0cc7d8ce572e8b6 (diff)
downloadhaskell-1941ef4f050c0dfcb68229641fcbbde3a10f1072.tar.gz
Modules: Types (#13009)
Update Haddock submodule Metric Increase: haddock.compiler
Diffstat (limited to 'compiler/typecheck/TcPatSyn.hs')
-rw-r--r--compiler/typecheck/TcPatSyn.hs26
1 files changed, 13 insertions, 13 deletions
diff --git a/compiler/typecheck/TcPatSyn.hs b/compiler/typecheck/TcPatSyn.hs
index a81ae283fd..c2e512df0d 100644
--- a/compiler/typecheck/TcPatSyn.hs
+++ b/compiler/typecheck/TcPatSyn.hs
@@ -27,19 +27,19 @@ import TcEnv
import TcMType
import TcHsSyn
import TysPrim
-import Name
-import SrcLoc
+import GHC.Types.Name
+import GHC.Types.SrcLoc
import GHC.Core.PatSyn
-import NameSet
+import GHC.Types.Name.Set
import Panic
import Outputable
import FastString
-import Var
-import VarEnv( emptyTidyEnv, mkInScopeSet )
-import Id
-import IdInfo( RecSelParent(..), setLevityInfoWithType )
+import GHC.Types.Var
+import GHC.Types.Var.Env( emptyTidyEnv, mkInScopeSet )
+import GHC.Types.Id
+import GHC.Types.Id.Info( RecSelParent(..), setLevityInfoWithType )
import TcBinds
-import BasicTypes
+import GHC.Types.Basic
import TcSimplify
import TcUnify
import GHC.Core.Predicate
@@ -48,11 +48,11 @@ import TcType
import TcEvidence
import TcOrigin
import BuildTyCl
-import VarSet
-import MkId
+import GHC.Types.Var.Set
+import GHC.Types.Id.Make
import TcTyDecls
import GHC.Core.ConLike
-import FieldLabel
+import GHC.Types.FieldLabel
import Bag
import Util
import ErrUtils
@@ -714,7 +714,7 @@ tcPatSynMatcher (L loc name) lpat
; let matcher_tau = mkVisFunTys [pat_ty, cont_ty, fail_ty] res_ty
matcher_sigma = mkInfSigmaTy (rr_tv:res_tv:univ_tvs) req_theta matcher_tau
matcher_id = mkExportedVanillaId matcher_name matcher_sigma
- -- See Note [Exported LocalIds] in Id
+ -- See Note [Exported LocalIds] in GHC.Types.Id
inst_wrap = mkWpEvApps prov_dicts <.> mkWpTyApps ex_tys
cont' = foldl' nlHsApp (mkLHsWrap inst_wrap (nlHsVar cont)) cont_args
@@ -803,7 +803,7 @@ mkPatSynBuilderId dir (L _ name)
mkVisFunTys arg_tys $
pat_ty
builder_id = mkExportedVanillaId builder_name builder_sigma
- -- See Note [Exported LocalIds] in Id
+ -- See Note [Exported LocalIds] in GHC.Types.Id
builder_id' = modifyIdInfo (`setLevityInfoWithType` pat_ty) builder_id